from datetime import datetime
import time
from plyer import notification


def check_day_status():
    return 1 <= datetime.today().isoweekday() <= 5


def notifier_weekday(weekend_mess):
    notification.notify(
        title=weekend_mess,
        message="Have a good day",
        app_icon=r"sea_fishes.ico",
        timeout=60
    )


def notifier_break():
    notification.notify(
        title="Break",
        message="Rest for 10 minutes before continue working",
        app_icon=r"break.ico",
        timeout=60*10
    )
    time.sleep(60*10)


def notifier_lunch():
    notification.notify(
        title="Lunch Time",
        message="Go and eat something delicious",
        app_icon=r"food.ico",
        timeout=60*60
    )
    time.sleep(60*60)


def notifier_end_workday():
    notification.notify(
        title="The end!",
        message="See you tomorrow",
        app_icon=r"end.ico",
        timeout=60
    )
    time.sleep(10)


def notifier_workday(workday_mess, num):
    notification.notify(
        title=workday_mess + f"Session {num}/8",
        message="Work is in progress...",
        app_icon=r"sea_fishes.ico",
        timeout=60 * 50
    )
    time.sleep(60 * 50)


def notifier(workday_mess):
    for num in range(1, 9):
        notifier_workday(workday_mess, num)
        if num == 4:
            notifier_lunch()
        elif num == 8:
            notifier_end_workday()
        else:
            notifier_break()





import calendar
from datetime import datetime

from notifier.main import check_day_status, notifier, notifier_weekday


def start_notifier():
    if check_day_status():
        input_message = f"Working hours for {calendar.day_name[datetime.today().weekday()]}\n"
        notifier(input_message)
    else:
        input_message = f"Today is {calendar.day_name[datetime.today().weekday()]}! Take a break!"
        notifier_weekday(input_message)

if __name__ == "__main__":
    start_notifier()



import pathlib
from setuptools import setup, find_packages
import sys

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="notipy-py",
    version="1.0.3",
    description="Windows notifier for 9-hours working day using Pomadoro technique "
                "(50 minutes work and 10 minutes rest) with lunch break",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/VladaZakharova/Notifier",
    author="Vlada Zakharova",
    author_email="vladazaharova0@gmail.com",
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        "Programming Language :: Python :: 3.7",
    ],
    packages=find_packages(exclude=("venv", ".git",)),
    include_package_data=True,
    install_requires=[
        "notifier==1.0.3",
        "plyer==2.0.0"
    ],
    entry_points={
        "console_scripts": [
            "notifier=notifier.__main__:start_notifier",
        ]
    },
)